@@ -1,5 +1,5 @@
 import re
-from datetime import datetime, timedelta, timezone, tzinfo
+from datetime import datetime, time, timedelta, timezone, tzinfo
 from typing import Optional
 
 import pytz
@@ -9,6 +9,10 @@ JP_TIMEZONE = pytz.timezone('Japan')
 NA_TIMEZONE = timezone(timedelta(hours=-8))
 KR_TIMEZONE = pytz.timezone('Asia/Seoul')
 
+DAY_CHANGE = time(0)
+ROLLOVER = time(4)
+
+
 def tzstr_to_timezone(self, tzstr: str) -> Optional[tzinfo]:
     tzstr = tzstr.upper().strip()
     if tzstr in ('EST', 'EDT', 'ET'):
@@ -38,3 +42,17 @@ def tzstr_to_timezone(self, tzstr: str) -> Optional[tzinfo]:
     for tz in pytz.all_timezones:
         if tzstr in tz.upper():
             return pytz.timezone(tz)
+
+
+def get_last_time(time_when: time, tz: Optional[tzinfo] = None) -> datetime:
+    dt = datetime.combine(datetime.now(tz).date(), time_when, tz)
+    if datetime.now(tz) < dt:
+        dt -= timedelta(days=1)
+    return dt
+
+
+def get_next_time(time_when: time, tz: Optional[tzinfo] = None) -> datetime:
+    dt = datetime.combine(datetime.now(tz).date(), time_when, tz)
+    if datetime.now(tz) > dt:
+        dt += timedelta(days=1)
+    return dt
